# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2021-06-08 16:07
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('track_actions', '0002_history_path'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='history',
            name=b'path',
        ),
        migrations.RemoveField(
            model_name='history',
            name=b'request_data',
        ),
        migrations.RemoveField(
            model_name='history',
            name=b'response_data',
        ),
        migrations.AlterField(
            model_name='history',
            name='action',
            field=models.TextField(blank=True, null=True),
        ),
    ]
