# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2021-06-09 17:26
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('track_actions', '0004_history_field_name'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='history',
            options={'ordering': ('-created_at',), 'verbose_name_plural': 'History model'},
        ),
    ]
